@@ -44,12 +44,10 @@
 
 using namespace KgpgCore;
 
-KgpgTrustLabel::KgpgTrustLabel(QWidget *parent, const QString &text, const QColor &color)
+KgpgTrustLabel::KgpgTrustLabel(QWidget *parent)
 	: QWidget(parent),
 	m_text_w(new QLabel(this)),
-	m_color_w(new QLabel(this)),
-	m_text(text),
-	m_color(color)
+	m_color_w(new QLabel(this))
 {
     m_text_w->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
@@ -103,6 +101,7 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
 	keychange(new KGpgChangeKey(node, this)),
 	m_node(node),
 	m_model(model),
+	m_trust(new KgpgTrustLabel(this)),
 	m_keywaschanged(false),
 	m_closewhendone(false)
 {
@@ -110,6 +109,11 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
 	Q_ASSERT(m_node != Q_NULLPTR);
 
     setupUi(this);
+    m_owtrust->addItem(Convert::toString(GPGME_VALIDITY_UNDEFINED));
+    m_owtrust->addItem(Convert::toString(GPGME_VALIDITY_NEVER));
+    m_owtrust->addItem(Convert::toString(GPGME_VALIDITY_MARGINAL));
+    m_owtrust->addItem(Convert::toString(GPGME_VALIDITY_FULL));
+    m_owtrust->addItem(Convert::toString(GPGME_VALIDITY_ULTIMATE));
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QWidget *mainWidget = new QWidget(this);
@@ -127,7 +131,6 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
     buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 
     m_email->setUnderline(false);
-    m_trust = new KgpgTrustLabel(this);
     int trustRow;
     formLayout_keyproperties->getWidgetPosition(tl_trust, &trustRow, Q_NULLPTR);
     formLayout_keyproperties->setWidget(trustRow, QFormLayout::FieldRole, m_trust);
