@@ -25,8 +25,10 @@
 #include "transactions/kgpgimport.h"
 
 #include <KConfigGroup>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <KUrlMimeData>
+
 #include <QDrag>
 #include <QDragMoveEvent>
 #include <QDropEvent>
@@ -51,7 +53,7 @@ KeyTreeView::selectedNodes(bool *psame, KgpgCore::KgpgItemType *pt) const
 	KgpgItemType tp = 0;
 	bool sametype = true;
 
-	if (selidx.count() == 0) {
+	if (selidx.isEmpty()) {
 		if (pt != Q_NULLPTR)
 			*pt = tp;
 		if (psame != Q_NULLPTR)
@@ -157,13 +159,13 @@ KeyTreeView::saveLayout(KConfigGroup &cg) const
 void
 KeyTreeView::contentsDragMoveEvent(QDragMoveEvent *e)
 {
-	e->setAccepted(KUrl::List::canDecode(e->mimeData()));
+	e->setAccepted(e->mimeData()->hasUrls());
 }
 
 void
 KeyTreeView::contentsDropEvent(QDropEvent *o)
 {
-	KUrl::List uriList = KUrl::List::fromMimeData(o->mimeData());
+	QList<QUrl> uriList = KUrlMimeData::urlsFromMimeData(o->mimeData());
 	if (!uriList.isEmpty()) {
 		if (KMessageBox::questionYesNo(this, i18n("<p>Do you want to import file <b>%1</b> into your key ring?</p>",
 					uriList.first().path()), QString(), KGuiItem(i18n("Import")),
