@@ -18,16 +18,28 @@
 #include <QString>
 #include <QStringList>
 
+static QStringList keyFingerprints(const KGpgKeyNode::List &keys)
+{
+	QStringList ret;
+
+	foreach (const KGpgKeyNode *key, keys)
+		ret << key->getFingerprint();
+
+	return ret;
+}
+
 KGpgDelKey::KGpgDelKey(QObject *parent, KGpgKeyNode *key)
 	: KGpgTransaction(parent)
+	, keys({key})
+	, fingerprints(keyFingerprints(keys))
 {
-	m_keys << key;
 	setCmdLine();
 }
 
 KGpgDelKey::KGpgDelKey(QObject *parent, const KGpgKeyNode::List &keys)
-	: KGpgTransaction(parent),
-	m_keys(keys)
+	: KGpgTransaction(parent)
+	, keys(keys)
+	, fingerprints(keyFingerprints(keys))
 {
 	setCmdLine();
 }
@@ -36,16 +48,12 @@ KGpgDelKey::~KGpgDelKey()
 {
 }
 
-KGpgKeyNode::List
-KGpgDelKey::keys() const
-{
-	return m_keys;
-}
-
 bool
 KGpgDelKey::nextLine(const QString &line)
 {
-	if (!line.startsWith(QLatin1String("[GNUPG:] GOT_IT")))
+	if (keyConsidered(line, fingerprints)) {
+		// nothing
+	} else if (!line.startsWith(QLatin1String("[GNUPG:] GOT_IT")))
 		setSuccess(KGpgTransaction::TS_MSG_SEQUENCE);
 
 	return false;
@@ -67,10 +75,7 @@ bool
 KGpgDelKey::preStart()
 {
 	GPGProc *proc = getProcess();
-	QStringList args = proc->program();
-
-	foreach (const KGpgKeyNode *key, m_keys)
-		args << key->getFingerprint();
+	const QStringList args = proc->program() + fingerprints;
 
 	proc->setProgram(args);
 
